# Torch Inference Workflow Test
Given that pytorch requires that the model exist in the classpath, the
[`iris_classification_model.py`](./iris_classification_model.py) and
[`test_torch_inference_workflow.py`](./test_torch_inference_workflow.py) are put in the
same directory. This is just done for cleanliness of the tests structure.
